@@ -1,5 +1,5 @@
 package SimpleDB::Class::Item;
-our $VERSION = '1.0200';
+our $VERSION = '1.0300';
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ SimpleDB::Class::Item - An object representation from an item in a SimpleDB doma
 
 =head1 VERSION
 
-version 1.0200
+version 1.0300
 
 =head1 DESCRIPTION
 
@@ -136,23 +136,77 @@ The class name of the class you're creating the child relationship with.
 
 The attribute in the child class that represents this class' id.
 
-=head3 mate
+=head3 options
 
-Optional. The name of the attribute that will be created in C<class> to refer back to this object. If specified, a reference to this object will be set in C<class> when it is instantiated to avoid stale references.
+A hash containing options that will modify the method created.
+
+=head4 mate
+
+The name of the attribute that will be created in C<class> to refer back to this object. If specified, a reference to this object will be set in C<class> when it is instantiated to avoid stale references.
+
+=head4 consistent
+
+A boolean which can enable SimpleDB's ConsistentRead option. Defaults to 0.
+
+=head2 I<has_many_generated_method> ( [ options ] )
+
+This is the documentation for the method generated by C<has_many>. It returns a L<SimpleDB::Class::ResultSet> object with a list of the related children to this class.
+
+=head3 options
+
+A hash of options to modify the result set at run time.
+
+=head4 where
+
+A where clause as defined by L<SimpleDB::Class::SQL>. This new clause will automatically be added to the relationship clause, so whatever you specify here is only to further limit the results returned.
+
+=head4 order_by 
+
+An order_by clause as defined by L<SimpleDB::Class::SQL>. By default no order is specified.
+
+=head4 limit
+
+A limit clause as defined by L<SimpleDB::Class::SQL>. By default all items in the relationship will be returned.
+
+=head4 consistent
+
+A boolean that can enable SimpleDB's ConsistentRead option. Setting this will override whatever was set in C<has_many>, if anything.
+
+=head4 set
+
+A hash reference of attribute names and values that will be applied to each object returned from the result set. The C<mate> option in C<has_many> can already set one of these.
 
 =cut
 
 sub has_many {
-    my ($class, $name, $classname, $attribute, $mate) = @_;
+    my ($class, $name, $classname, $attribute, %options) = @_;
     _install_sub($class.'::'.$name, sub { 
-        my $self = shift; 
-        my %options = (
+        my ($self, %sub_options) = @_; 
+        my %search_options = (
             where => {$attribute => $self->id},
         );
-        if ($mate) {
-            $options{set} = { $mate => $self };
+        if (exists $sub_options{where}) {
+            $search_options{where}{'-and'} = $sub_options{where};
         }
-        return $self->simpledb->domain($classname)->search(%options); 
+        if ($sub_options{order_by}) {
+            $search_options{order_by} = $sub_options{order_by};
+        }
+        if ($sub_options{limit}) {
+            $search_options{limit} = $sub_options{limit};
+        }
+        if (exists $sub_options{set}) {
+            $search_options{set} = $sub_options{set};
+        }
+        if ($options{mate}) {
+            $search_options{set}{$options{mate}} = $self;
+        }
+        if (exists $options{consistent}) {
+            $search_options{consistent} = $options{consistent};
+        }
+        if (exists $sub_options{consistent}) {
+            $search_options{consistent} = $sub_options{consistent};
+        }
+        return $self->simpledb->domain($classname)->search(%search_options); 
     });
 }
 
@@ -162,13 +216,9 @@ sub has_many {
 
 Class method. Adds a 1:N relationship between another class and this one.
 
-B<Note:> The generated method will return C<undef> if the attribute specified has no value at the time it is called.
-
 =head3 method
 
-The method name to create to represent this relationship in this class.
-
-B<NOTE:> A C<clear_*()> method will be created as well, which will uncache the result. This method will be automatically called if a new value is set for the attribute.
+The method name to create to represent this relationship in this class. 
 
 =head3 class
 
@@ -178,16 +228,42 @@ The class name of the parent class you're relating this class to.
 
 The attribute in this class' attribute list that represents the id of the parent class.
 
-=head3 mate
+=head3 options
 
-Optional. The name of the attribute that will be created in C<class> to refer back to this object. If specified, a reference to this object will be set in C<class> when it is instantiated to avoid stale references. This would only be useful in the case of a 1:1 relationship.
+A hash of options to modify the created method.
+
+=head4 mate
+
+The name of the attribute that will be created in C<class> to refer back to this object. If specified, a reference to this object will be set in C<class> when it is instantiated to avoid stale references. This would only be useful in the case of a 1:1 relationship.
+
+=head4 consistent
+
+A boolean indicating whether to enable the SimpleDB's ConsistentRead option.
+
+=head2 I<belongs_to_generated_method> ( [ item ] )
+
+This is the documentation for the method that C<belongs_to> generates. This method caches the item it retrieves for faster future retrievals.
+
+B<NOTE:> Will return C<undef> if the attribute specified has no value at the time it is called.
+
+=head3 item
+
+You can optionally precache the item that this method would produce, if you already have it by passing it to the method here. If you choose to use this option, make sure what you're setting here actually matches the id attribute that would normally be used to find the item in question.
+
+=head2 has_I<belongs_to_generated_method>
+
+Returns a boolean indicating whether the generated method is storing a cached result.
+
+=head2 clear_I<belongs_to_generated_method>
+
+Clears the cached result stored by the generated method. This method will be automatically called if a new value is set for the attribute.
 
 =cut
 
-
 sub belongs_to {
-    my ($class, $name, $classname, $attribute, $mate) = @_;
+    my ($class, $name, $classname, $attribute, %options) = @_;
     my $clearer = 'clear_'.$name;
+    my $predicate = 'has_'.$name;
     $class->meta->add_attribute($name, {
         is      => 'rw',
         lazy    => 1,
@@ -195,12 +271,16 @@ sub belongs_to {
                 my $self = shift;
                 my $id = $self->$attribute;
                 return undef unless ($id ne '');
-                my %options;
-                if ($mate) {
-                    $options{set} = { $mate => $self };
+                my %find_options;
+                if ($options{mate}) {
+                    $find_options{set} = { $options{mate} => $self };
                 }
-                return $self->simpledb->domain($classname)->find($id, %options);
+                if (exists $options{consistent}) {
+                    $find_options{consistent} = $options{consistent};
+                }
+                return $self->simpledb->domain($classname)->find($id, %find_options);
             },
+        predicate => $predicate,
         clearer => $clearer,
         });
     $class->meta->add_after_method_modifier($attribute, sub {
